/**************************************************************************/
/* This program is used to monitor the event messages.  This will wait on */
/* event queues and get the message if an event generated and display it  */
/* to a file of monitor after formatting the message into a readable form.*/
/*                                                                        */
/* This need to compile as shared memory and can call it from a main      */
/* program.                                                               */
/*                                                                        */
/*   Author : Sanjeev S on 18th March, 2002                               */
/**************************************************************************/

 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <cmqc.h>
 #include <cmqcfc.h>
 #include <cmqxc.h>

 /* function prototypes */

 int strVal(MQCFST* parmst, FILE* st, char outTypeSt);
 int intVal(MQCFIN* parmin, FILE* in, char outTypeIn);
 int dispReason(MQLONG dspRes, FILE *dr, char outTypeDs);

 evPerfm(char *QMgrName,char *objName,char outType,int wTime) 
 {

   FILE *fp;
   /*   Declare MQI structures needed                                */
   MQOD     od = {MQOD_DEFAULT};    /* Object Descriptor             */
   MQMD     md = {MQMD_DEFAULT};    /* Message Descriptor            */
   MQGMO   gmo = {MQGMO_DEFAULT};   /* get message options           */
      /** note, sample uses defaults where it can **/

   MQHCONN  Hcon;                   /* connection handle             */
   MQHOBJ   Hobj;                   /* object handle                 */
   MQLONG   O_options;              /* MQOPEN options                */
   MQLONG   C_options;              /* MQCLOSE options               */
   MQLONG   CompCode;               /* completion code               */
   MQLONG   OpenCode;               /* MQOPEN completion code        */
   MQLONG   Reason;                 /* reason code                   */
   MQLONG   CReason;                /* reason code for MQCONN        */
   MQCFH    *buffer;
   MQLONG   buflen;                 /* buffer length                 */
   MQLONG   messlen;                /* message length received       */
   MQCFST   *parms;
   char     QMName[50], evtype[100];
   long     retInt;
   int      counter,rc;


   strcpy(od.ObjectName, objName);
   strcpy(QMName, QMgrName);
  
   /******************************************************************/
   /*   Connect to queue manager                                     */
   /******************************************************************/
   MQCONN(QMName,                  /* queue manager                  */
          &Hcon,                   /* connection handle              */
          &CompCode,               /* completion code                */
          &CReason);               /* reason code                    */

   if (CompCode == MQCC_FAILED)
   {
     printf("ERROR: MQCONN ended with reason code %ld\n", CReason);
     return -1;
   }

   O_options = MQOO_INPUT_AS_Q_DEF   /* open queue for input         */
         + MQOO_FAIL_IF_QUIESCING;   /* but not if MQM stopping      */
   MQOPEN(Hcon,                      /* connection handle            */
          &od,                       /* object descriptor for queue  */
          O_options,                 /* open options                 */
          &Hobj,                     /* object handle                */
          &OpenCode,                 /* completion code              */
          &Reason);                  /* reason code                  */

   if (Reason != MQRC_NONE)
   {
     if (Reason == MQRC_OBJECT_IN_USE)
         return 0;
     printf("ERROR: MQOPEN ended with reason code %ld\n", Reason);
     return -1;
   }

   if (OpenCode == MQCC_FAILED)
   {
     printf("ERROR: unable to open queue for input\n");
     return -1;
   }

   CompCode = OpenCode;       /* use MQOPEN result for initial test  */
                                      /* every MQGET                 */
   gmo.Options = MQGMO_WAIT       /* wait for new messages           */
               + MQGMO_ACCEPT_TRUNCATED_MSG
               + MQGMO_CONVERT;   /* convert if necessary            */
   gmo.WaitInterval = wTime; 

   while (CompCode != MQCC_FAILED)
   {
     buflen = sizeof(buffer) - 1; /* buffer size available for GET   */
     buflen = 300;
     buffer = malloc(buflen);
     memcpy(md.MsgId, MQMI_NONE, sizeof(md.MsgId));
     memcpy(md.CorrelId, MQCI_NONE, sizeof(md.CorrelId));

     md.Encoding       = MQENC_NATIVE;
     md.CodedCharSetId = MQCCSI_Q_MGR;
   
     MQGET(Hcon,                /* connection handle                 */
           Hobj,                /* object handle                     */
           &md,                 /* message descriptor                */
           &gmo,                /* get message options               */
           buflen,              /* buffer length                     */
           buffer,              /* message buffer                    */
           &messlen,            /* message length                    */
           &CompCode,           /* completion code                   */
           &Reason);            /* reason code                       */

     if (Reason != MQRC_NONE)
     {

         /*   treat truncated message as a failure for this sample   */
         if (Reason == MQRC_TRUNCATED_MSG_FAILED)
         {
           CompCode = MQCC_FAILED;
         }
     }

     if (CompCode != MQCC_FAILED)
     {

       if ( buffer->Type != MQCFT_EVENT )
       {
         printf("ERROR: This is not an event message\n");
         return -1;
       }

       if(outType == 'B' || outType == 'F')
           fp = fopen("evmon.log", "a+");

       /*************************************************************/
       /* get the values from the event header MQCFH                */ 
       /*************************************************************/

       switch ( buffer->Command )
       {
          case MQCMD_Q_MGR_EVENT:
               strcpy(evtype, "QMGR EVENT");
               break;
          case MQCMD_PERFM_EVENT:
               strcpy(evtype, "PERFORMANCE EVENT");
               break;
          case MQCMD_CHANNEL_EVENT:
               strcpy(evtype, "CHANNEL EVENT");
               break;
          default:
               printf("Unknown event type\n");
               break;
       } 

       dispReason( buffer->Reason, fp, outType );

       if(outType == 'B' || outType == 'S')
       {
         printf("Event type                    : %s\n", evtype);
         printf("Event Put Date                : %c%c%c%c/%c%c/%c%c\n"
                "Event Put Time                : %c%c:%c%c:%c%c\n",
                                               md.PutDate[0],
                                               md.PutDate[1],
                                               md.PutDate[2],
                                               md.PutDate[3],
                                               md.PutDate[4],
                                               md.PutDate[5],
                                               md.PutDate[6],
                                               md.PutDate[7],
                                               md.PutTime[0],
                                               md.PutTime[1],
                                               md.PutTime[2],
                                               md.PutTime[3],
                                               md.PutTime[4],
                                               md.PutTime[5]);
       }
      
       if(outType == 'B' || outType == 'F')
       { 
         fprintf(fp, "Event type                    : %s\n",evtype); 
         fprintf(fp, "Event Put Date                : %c%c%c%c/%c%c/%c%c\n"
                     "Event Put Time                : %c%c:%c%c:%c%c\n",
                                                    md.PutDate[0],
                                                    md.PutDate[1],
                                                    md.PutDate[2],
                                                    md.PutDate[3],
                                                    md.PutDate[4],
                                                    md.PutDate[5],
                                                    md.PutDate[6],
                                                    md.PutDate[7],
                                                    md.PutTime[0],
                                                    md.PutTime[1],
                                                    md.PutTime[2],
                                                    md.PutTime[3],
                                                    md.PutTime[4],
                                                    md.PutTime[5]);
       }
   
       parms = (MQCFST*) (buffer + 1);
       for(counter = 0; counter < buffer->ParameterCount; counter++)
       {
          switch ( parms->Type )
          {
            case MQCFT_STRING:
                 rc = strVal(parms,fp,outType);
                 parms = (MQCFST*) ((char*)parms + parms->StrucLength);
                 break;
            case MQCFT_INTEGER:
                 rc = intVal((MQCFIN*)parms,fp,outType);
                 parms = (MQCFST*) ((char*)parms + parms->StrucLength);
                 break;
            default:
                 printf("ERROR: Unknown structure type\n");
                 break;
          }
       }

       if(outType == 'B' || outType == 'S')
          printf("-----------------------------------------------------------\n");

       if(outType == 'B' || outType == 'F')
       {
          fprintf(fp,"-----------------------------------------------------------\n");
          fclose(fp);
       }
     } /* end of CompCode is not showing failure loop */
   }

   if (OpenCode != MQCC_FAILED)
   {
     C_options = 0;                   /* no close options            */
     MQCLOSE(Hcon,                    /* connection handle           */
             &Hobj,                   /* object handle               */
             C_options,
             &CompCode,               /* completion code             */
             &Reason);                /* reason code                 */

     /* report reason, if any     */
     if (Reason != MQRC_NONE)
     {
       printf("ERROR: MQCLOSE ended with reason code %ld\n", Reason);
       return -1;
     }
   }

   if (CReason != MQRC_ALREADY_CONNECTED )
   {
     MQDISC(&Hcon,                     /* connection handle          */
            &CompCode,                 /* completion code            */
            &Reason);                  /* reason code                */

     /* report reason, if any     */
     if (Reason != MQRC_NONE)
     {
       printf("ERROR: MQDISC ended with reason code %ld\n", Reason);
       return -1;
     }
   }

   /******************************************************************/
   /*       end of evmon main function                               */
   /******************************************************************/
   return 0;
 }

/******************************************************************/
/*  function to retrieve event data from MQCFST structure         */
/******************************************************************/

int strVal(MQCFST* parmst, FILE* st, char outTypeSt)
{
   char parm[100],strParm[100];
   switch(parmst->Parameter)
   {
	case MQCA_Q_MGR_NAME:
                strcpy(parm, "MQCA_Q_MGR_NAME               :");
		break;
	case MQCA_Q_NAME:
		strcpy(parm, "MQCA_Q_NAME                   :");
		break;
	case MQCACF_APPL_NAME:
		strcpy(parm, "MQCACF_APPL_NAME              :");
		break;
	case MQCACF_OBJECT_Q_MGR_NAME:
		strcpy(parm, "MQCACF_OBJECT_Q_MGR_NAME      :");
		break;
	case MQCACF_BRIDGE_NAME:
		strcpy(parm, "MQCACF_BRIDGE_NAME            :");
		break;
	case MQCACH_CHANNEL_NAME:
		strcpy(parm, "MQCACH_CHANNEL_NAME           :");
		break;
	case MQCACH_XMIT_Q_NAME:
		strcpy(parm, "MQCACH_XMIT_Q_NAME            :");
		break;
	case MQCACH_CONNECTION_NAME:
		strcpy(parm, "MQCACH_CONNECTION_NAME        :");
		break;
	case MQCACH_FORMAT_NAME:
		strcpy(parm, "MQCACH_FORMAT_NAME            :");
		break;
	case MQCACF_AUX_ERROR_DATA_STR_1:
		strcpy(parm, "MQCACF_AUX_ERROR_DATA_STR_1   :");
		break;
	case MQCACF_AUX_ERROR_DATA_STR_2:
		strcpy(parm, "MQCACF_AUX_ERROR_DATA_STR_2   :");
		break;
	case MQCACF_AUX_ERROR_DATA_STR_3:
		strcpy(parm, "MQCACF_AUX_ERROR_DATA_STR_3   :");
		break;
	case MQCACF_USER_IDENTIFIER:
		strcpy(parm, "MQCACF_USER_IDENTIFIER        :");
		break;
	case MQCA_PROCESS_NAME:
		strcpy(parm, "MQCA_PROCESS_NAME             :");
		break;
	case MQCA_BASE_Q_NAME:
		strcpy(parm, "MQCA_BASE_Q_NAME              :");
		break;
   }
   strcpy(strParm, parmst->String);
   if(outTypeSt == 'B' || outTypeSt == 'S')
       printf("%s %s\n",parm, strParm);

   if(outTypeSt == 'B' || outTypeSt == 'F')
       fprintf(st, "%s %s\n",parm, strParm);
   
   return 0;
} /* end of function */

/****************************************************************/
/*  function to get event data from MQCFIN structure            */
/****************************************************************/

int intVal(MQCFIN* parmint, FILE* in, char outTypeIn)
{
   char parmin[100], val[100];
   int flag=0;

   switch(parmint->Parameter)
   {
    	case MQIA_Q_TYPE:
         	strcpy(parmin, "MQIA_Q_TYPE                   :");
         	break;
	case MQIA_APPL_TYPE:
         	strcpy(parmin, "MQIA_APPL_TYPE                :");
  		break;
	case MQIACF_BRIDGE_TYPE:
         	strcpy(parmin, "MQIA_BRIDGE_TYPE              :");
		break;
	case MQIACF_REASON_QUALIFIER:
         	strcpy(parmin, "MQIACF_REASON_QUALIFIER       :");
		break;
	case MQIACF_ERROR_IDENTIFIER:
         	strcpy(parmin, "MQIACF_ERROR_IDENTIFIER       :");
		break;
	case MQIACH_CHANNEL_TYPE:
         	strcpy(parmin, "MQIACH_CHANNEL_TYPE           :");
		break;
	case MQIACF_AUX_ERROR_DATA_INT_1:
         	strcpy(parmin, "MQIACF_AUX_DATA_INT_1         :");
		break;
	case MQIACF_CONV_REASON_CODE:
         	strcpy(parmin, "MQIACF_CONV_REASON_CODE       :");
		break;
	case MQIACF_AUX_ERROR_DATA_INT_2:
         	strcpy(parmin, "MQIACF_AUX_ERROR_DATA_INT_2   :");
		break;
	case MQIACF_OPEN_OPTIONS:
         	strcpy(parmin, "MQIACF_OPEN_OPTIONS           :");
		break;
	case MQIACF_COMMAND:
         	strcpy(parmin, "MQIACF_COMMAND                :");
		break;
	case MQIA_TIME_SINCE_RESET:
         	strcpy(parmin, "MQIA_TIME_SINCE_RESET         :");
		break;
	case MQIA_HIGH_Q_DEPTH:
         	strcpy(parmin, "MQIA_HIGH_Q_DEPTH             :");
		break;
	case MQIA_MSG_ENQ_COUNT:
         	strcpy(parmin, "MQIA_MSG_ENQ_COUNT            :");
		break;
	case MQIA_MSG_DEQ_COUNT:
         	strcpy(parmin, "MQIA_MSG_DEQ_COUNT            :");
		break;
   }
   switch(parmint->Value)
   {
	case MQRQ_BRIDGE_STOPPED_OK:
         	strcpy(val, "MQRQ_BRIDGE_STOPPED");
		break;
	case MQBT_OTMA:
         	strcpy(val, "MQBT_OTMA");
		break;
	case MQRQ_BRIDGE_STOPPED_ERROR:
         	strcpy(val, "MQRQ_BRIDGE_STOPPED_ERROR");
		break;
	case MQQT_ALIAS:
         	strcpy(val, "MQQT_ALIAS");
		break;
	case MQQT_MODEL:
         	strcpy(val, "MQQT_MODEL");
		break;
	case MQRCCF_SUPPRESSED_BY_EXIT:
         	strcpy(val, "MQCCF_SUPPRESSED_BY_EDIT");
		break;
	case MQRC_CONVERTED_MSG_TOO_BIG:
         	strcpy(val, "MQRC_CONVERTED_MSG_TOO_BIG");
		break;
	case MQRC_FORMAT_ERROR:
         	strcpy(val, "MQRC_FORMAT_ERROR");
		break;
	case MQRC_NOT_CONVERTED:
         	strcpy(val, "MQRC_NOT_VONVERTED");
		break;
	case MQRC_SOURCE_CCSID_ERROR:
         	strcpy(val, "MQRC_SOURCE_CCSID_ERROR");
		break;
	case MQQT_REMOTE:
         	strcpy(val, "MQQT_REMOTE");
		break;
	case MQRQ_Q_MGR_STOPPING:
         	strcpy(val, "MQRQ_Q_MGR_STOPPING");
		break;
	case MQRC_SOURCE_DECIMAL_ENC_ERROR:
         	strcpy(val, "MQRC_SOURCE_DECIMAL_ENC_ERR");
		break;
	case MQRC_SOURCE_FLOAT_ENC_ERROR:
         	strcpy(val, "MQRC_SOURCE_FLOAT_ENC_ERROR");
		break;
	case MQRC_SOURCE_INTEGER_ENC_ERROR:
         	strcpy(val, "MQRC_SOURCE_INTEGER_ENC_ERR");
		break;
	case MQRC_TARGET_CCSID_ERROR:
         	strcpy(val, "MQRC_TARGET_CCSID_ERROR");
		break;
	case MQRC_TARGET_DECIMAL_ENC_ERROR:
         	strcpy(val, "MQRC_TARGET_DECIMAL_ENC_ERR");
		break;
	case MQRC_TARGET_FLOAT_ENC_ERROR:
         	strcpy(val, "MQRC_TARGET_FLOAT_ENC_ERROR");
		break;
	case MQRC_TARGET_INTEGER_ENC_ERROR:
         	strcpy(val, "MQRC_TARGET_INTEGER_ENC_ERR");
		break;
	case MQRC_TRUNCATED_MSG_ACCEPTED:
         	strcpy(val, "MQRC_TRUNCATED_MSG_ACCEPTED");
		break;
	case MQRC_TRUNCATED_MSG_FAILED:
         	strcpy(val, "MQRC_TRUNCATED_MSG_FAILED");
		break;
	case MQRQ_CHANNEL_STOPPED_OK:
         	strcpy(val, "MQRQ_CHANNEL_STOPPED");
		break;
	case MQRQ_CHANNEL_STOPPED_RETRY:
         	strcpy(val, "MQRQ_CHANNEL_STOPPED_RETRY");
		break;
	case MQRQ_CHANNEL_STOPPED_ERROR:
         	strcpy(val, "MQRQ_CHANNEL_STOPPED_ERROR");
		break;
	case MQRQ_CHANNEL_STOPPED_DISABLED:
         	strcpy(val, "MQRQ_CHL_STOPPED_DISABLED");
		break;
        default:
                flag = 1;
		break;
   }
   if(flag == 1)
   {
      flag = 0;
      switch(parmint->Value)
      {
       	case MQRQ_CONN_NOT_AUTHORIZED:
         	strcpy(val, "MQRQ_CONN_NOT_AUTHORIZED");
		break;
	case MQRQ_OPEN_NOT_AUTHORIZED:
         	strcpy(val, "MQRQ_OPEN_NOT_AUTHORIZED");
		break;
	case MQCHT_RECEIVER:
         	strcpy(val, "MQCHT_RECEIVER");
		break;
	case MQCHT_SVRCONN:
         	strcpy(val, "MQCHT_SVRCONN");
		break;
	case MQCHT_CLUSSDR:
         	strcpy(val, "MQCHT_CLUSSDR");
		break;
  	default:
                flag = 1;		
                break;
      }
   }
   if(flag == 1)
   {
     flag = 0;
     switch(parmint->Value)
     {
	case MQRQ_CMD_NOT_AUTHORIZED:
         	strcpy(val, "MQRQ_CMD_NOT_AUTHORIZED");
		break;
	case MQRQ_CLOSE_NOT_AUTHORIZED:
         	strcpy(val, "MQRQ_CLOSE_NOT_AUTHORIZED");
		break;
     }
   }

   if(outTypeIn == 'B' || outTypeIn == 'S')
       printf("%s %s\n", parmin, val);

   if(outTypeIn == 'B' || outTypeIn == 'F')
       fprintf(in, "%s %s\n", parmin, val);
 
   return 0;
}  /* end of function */

/* Function for display reason */
int dispReason(MQLONG dspRes, FILE *dr, char outTypeDs)
{
        char rval[100];
        int dspfl;
        rval[0] = '\0';
	switch(dspRes)
        {
		case MQRCCF_CFH_TYPE_ERROR:
		     strcpy(rval, "MQRCCF_CFH_TYPE_ERROR");
		     break;
         	case MQRCCF_CFH_LENGTH_ERROR:
		     strcpy(rval, "MQRCCF_CFH_LENGTH_ERROR");
		     break;
    		case MQRCCF_CFH_VERSION_ERROR:
		     strcpy(rval, "MQRCCF_CFH_VERSION_ERROR");
		     break;
    		case MQRCCF_CFH_MSG_SEQ_NUMBER_ERR:
		     strcpy(rval, "MQRCCF_CFH_MSG_SEQ_NUMBER_ERROR");
		     break;
		case MQRCCF_CFH_CONTROL_ERROR:
		     strcpy(rval, "MQRCCF_CFH_CONTROL_ERROR");
		     break;
    		case MQRCCF_CFH_PARM_COUNT_ERROR:
		     strcpy(rval, "MQRCCF_CFH_PARM_COUNT_ERROR");
		     break;
    		case MQRCCF_CFH_COMMAND_ERROR:
		     strcpy(rval, "MQRCCF_CFH_COMMAND_ERROR");
		     break;
    		case MQRCCF_COMMAND_FAILED:
		     strcpy(rval, "MQRCCF_COMMAND_FAILED");
		     break;
    		case MQRCCF_CFIN_LENGTH_ERROR:
		     strcpy(rval, "MQRCCF_CFIN_LENGTH_ERROR");
		     break;
    		case MQRCCF_CFST_LENGTH_ERROR:
		     strcpy(rval, "MQRCCF_CFST_LENGTH_ERROR");
		     break;
    		case MQRCCF_CFST_STRING_LENGTH_ERR:
		     strcpy(rval, "MQRCCF_CFST_STRING_LENGTH_ERR");
		     break;
    		case MQRCCF_FORCE_VALUE_ERROR:
		     strcpy(rval, "MQRCCF_FORCE_VALUE_ERROR");
		     break;
    		case MQRCCF_STRUCTURE_TYPE_ERROR:
		     strcpy(rval, "MQRCCF_STRUCTURE_TYPE_ERROR");
		     break;
    		case MQRCCF_CFIN_PARM_ID_ERROR:
		     strcpy(rval, "MQRCCF_CFIN_PARM_ID_ERROR");
		     break;
    		case MQRCCF_CFST_PARM_ID_ERROR:
		     strcpy(rval, "MQRCCF_CFST_PARM_ID_ERROR");
		     break;
    		case MQRCCF_MSG_LENGTH_ERROR:
		     strcpy(rval, "MQRCCF_MSG_LENGTH_ERROR");
		     break;
    		case MQRCCF_CFIN_DUPLICATE_PARM:
		     strcpy(rval, "MQRCCF_CFIN_DUPLICATE_PARM");
		     break;
    		case MQRCCF_CFST_DUPLICATE_PARM:
		     strcpy(rval, "MQRCCF_CFST_DUPLICATE_PARM");
		     break;
    		case MQRCCF_PARM_COUNT_TOO_SMALL:
		     strcpy(rval, "MQRCCF_PARM_COUNT_TOO_SMALL");
		     break;
    		case MQRCCF_PARM_COUNT_TOO_BIG:
		     strcpy(rval, "MQRCCF_PARM_COUNT_TOO_BIG");
		     break;
    		case MQRCCF_Q_ALREADY_IN_CELL:
		     strcpy(rval, "MQRCCF_Q_ALREADY_IN_CELL");
		     break;
    		case MQRCCF_Q_TYPE_ERROR:
		     strcpy(rval, "MQRCCF_Q_TYPE_ERROR");
		     break;
    		case MQRCCF_MD_FORMAT_ERROR:
		     strcpy(rval, "MQRCCF_MD_FORMAT_ERROR");
		     break;
		case MQRCCF_REPLACE_VALUE_ERROR:
		     strcpy(rval, "MQRCCF_REPLACE_VALUE_ERROR");
		     break;
    		case MQRCCF_CFIL_DUPLICATE_VALUE:
		     strcpy(rval, "MQRCCF_CFIL_DUPLICATE_VALUE");
		     break;
    		case MQRCCF_CFIL_COUNT_ERROR:
		     strcpy(rval, "MQRCCF_CFIL_COUNT_ERROR");
		     break;
    		case MQRCCF_CFIL_LENGTH_ERROR:
		     strcpy(rval, "MQRCCF_CFIL_LENGTH_ERROR");
		     break;
    		case MQRCCF_QUIESCE_VALUE_ERROR:
		     strcpy(rval, "MQRCCF_QUIESCE_VALUE_ERROR");
		     break;
    		case MQRCCF_MSG_SEQ_NUMBER_ERROR:
		     strcpy(rval, "MQRCCF_MSG_SEQ_NUMBER_ERROR");
		     break;
    		case MQRCCF_PING_DATA_COUNT_ERROR:
		     strcpy(rval, "MQRCCF_PING_DATA_COUNT_ERROR");
		     break;
    		case MQRCCF_PING_DATA_COMPARE_ERROR:
		     strcpy(rval, "MQRCCF_PING_DATA_COMPARE_ERROR");
		     break;
    		case MQRCCF_CHANNEL_TYPE_ERROR:
		     strcpy(rval, "MQRCCF_CHANNEL_TYPE_ERROR");
		     break;
    		case MQRCCF_PARM_SEQUENCE_ERROR:
		     strcpy(rval, "MQRCCF_PARM_SEQUENCE_ERROR");
		     break;
    		case MQRCCF_XMIT_PROTOCOL_TYPE_ERR:
		     strcpy(rval, "MQRCCF_XMIT_PROTOCOL_TYPE_ERR");
		     break;
	        case MQRCCF_BATCH_SIZE_ERROR:
	             strcpy(rval, "MQRCCF_BATCH_SIZE_ERROR");
		     break;
	        case MQRCCF_DISC_INT_ERROR:
	             strcpy(rval, "MQRCCF_DISC_INT_ERROR");
		     break;
    		case MQRCCF_SHORT_RETRY_ERROR:
	             strcpy(rval, "MQRCCF_SHORT_RETRY_ERROR");
		     break;
    		case MQRCCF_SHORT_TIMER_ERROR:
	             strcpy(rval, "MQRCCF_SHORT_TIMER_ERROR");
		     break;
    		case MQRCCF_LONG_RETRY_ERROR:
	             strcpy(rval, "MQRCCF_SHORT_TIMER_ERROR");
		     break;
    		case MQRCCF_LONG_TIMER_ERROR:
	             strcpy(rval, "MQRCCF_LONG_TIMER_ERROR");
		     break;
    		case MQRCCF_SEQ_NUMBER_WRAP_ERROR:
	             strcpy(rval, "MQRCCF_SEQ_NUMBER_WRAP_ERROR");
		     break;
    		case MQRCCF_MAX_MSG_LENGTH_ERROR:
	             strcpy(rval, "MQRCCF_MAX_MSG_LENGTH_ERROR");
		     break;
    		case MQRCCF_PUT_AUTH_ERROR:
	             strcpy(rval, "MQRCCF_PUT_AUTH_ERROR");
		     break;
    		case MQRCCF_PURGE_VALUE_ERROR:
	             strcpy(rval, "MQRCCF_PURGE_VALUE_ERROR");
		     break;
    		case MQRCCF_CFIL_PARM_ID_ERROR:
	             strcpy(rval, "MQRCCF_CFIL_PARM_ID_ERROR");
		     break;
    		case MQRCCF_MSG_TRUNCATED:
	             strcpy(rval, "MQRCCF_MSG_TRUNCATED");
		     break;
    		case MQRCCF_CCSID_ERROR:
	             strcpy(rval, "MQRCCF_CCSID_ERROR");
		     break;
    		case MQRCCF_ENCODING_ERROR:
	             strcpy(rval, "MQRCCF_ENCODING_ERROR");
		     break;
    		case MQRCCF_DATA_CONV_VALUE_ERROR:
	             strcpy(rval, "MQRCCF_DATA_CONV_VALUE_ERROR");
		     break;
  	        case MQRCCF_INDOUBT_VALUE_ERROR:
	             strcpy(rval, "MQRCCF_INDOUBT_VALUE_ERROR");
		     break;
    		case MQRCCF_ESCAPE_TYPE_ERROR:
	             strcpy(rval, "MQRCCF_ESCAPE_TYPE_ERROR");
		     break;
    		case MQRCCF_CHANNEL_TABLE_ERROR:
	             strcpy(rval, "MQRCCF_CHANNEL_TABLE_ERROR");
		     break;
    		case MQRCCF_MCA_TYPE_ERROR:
	             strcpy(rval, "MQRCCF_MCA_TYPE_ERROR");
		     break;
    		case MQRCCF_CHL_INST_TYPE_ERROR:
	             strcpy(rval, "MQRCCF_CHL_INST_TYPE_ERROR");
		     break;
    		case MQRCCF_CHL_STATUS_NOT_FOUND:
	             strcpy(rval, "MQRCCF_CHL_STATUS_NOT_FOUND");
		     break;
    		case MQRCCF_OBJECT_ALREADY_EXISTS:
	             strcpy(rval, "MQRCCF_OBJECT_ALREADY_EXISTS");
		     break;
    		case MQRCCF_OBJECT_WRONG_TYPE:
	             strcpy(rval, "MQRCCF_OBJECT_WRONG_TYPE");
		     break;
    		case MQRCCF_LIKE_OBJECT_WRONG_TYPE:
	             strcpy(rval, "MQRCCF_LIKE_OBJECT_WRONG_TYPE");
		     break;
    		case MQRCCF_OBJECT_OPEN:
	             strcpy(rval, "MQRCCF_OBJECT_OPEN");
		     break;
    		case MQRCCF_ATTR_VALUE_ERROR:
	             strcpy(rval, "MQRCCF_ATTR_VALUE_ERROR");
		     break;
    		case MQRCCF_UNKNOWN_Q_MGR:
	             strcpy(rval, "MQRCCF_UNKNOWN_Q_MGR");
		     break;
    		case MQRCCF_Q_WRONG_TYPE:
	             strcpy(rval, "MQRCCF_UNKNOWN_Q_MGR");
		     break;
    		case MQRCCF_OBJECT_NAME_ERROR:
	             strcpy(rval, "MQRCCF_OBJECT_NAME_ERROR");
		     break;
    		case MQRCCF_ALLOCATE_FAILED:
	             strcpy(rval, "MQRCCF_ALLOCATE_FAILED");
		     break;
	        case MQRCCF_HOST_NOT_AVAILABLE:
	             strcpy(rval, "MQRCCF_HOST_NOT_AVAILABLE");
		     break;
    		case MQRCCF_CONFIGURATION_ERROR:
	             strcpy(rval, "MQRCCF_CONFIGURATION_ERROR");
		     break;
    		case MQRCCF_CONNECTION_REFUSED:
	             strcpy(rval, "MQRCCF_CONNECTION_REFUSED");
		     break;
    		case MQRCCF_ENTRY_ERROR:
	             strcpy(rval, "MQRCCF_ENTRY_ERROR");
		     break;
    		case MQRCCF_SEND_FAILED:
	             strcpy(rval, "MQRCCF_SEND_FAILDED");
		     break;
    		case MQRCCF_RECEIVED_DATA_ERROR:
	             strcpy(rval, "MQRCCF_RECEIVED_DATA_ERROR");
		     break;
    		case MQRCCF_RECEIVE_FAILED:
	             strcpy(rval, "MQRCCF_RECEIVE_FAILED");
		     break;
    		case MQRCCF_CONNECTION_CLOSED:
	             strcpy(rval, "MQRCCF_CONNECTION_CLOSED");
		     break;
    		case MQRCCF_NO_STORAGE:
	             strcpy(rval, "MQRCCF_NO_STORAGE");
		     break;
    		case MQRCCF_NO_COMMS_MANAGER:
	             strcpy(rval, "MQRCCF_NO_COMMS_MANAGER");
		     break;
    		case MQRCCF_LISTENER_NOT_STARTED:
	             strcpy(rval, "MQRCCF_LISTENER_NOT_STARTED");
		     break;
    		case MQRCCF_BIND_FAILED:
	             strcpy(rval, "MQRCCF_BIND_FAILED");
		     break;
    		case MQRCCF_CHANNEL_INDOUBT:
	             strcpy(rval, "MQRCCF_CHANNEL_INDOUBT");
		     break;
    		case MQRCCF_MQCONN_FAILED:
	             strcpy(rval, "MQRCCF_MQCONN_FAILED");
		     break;
    		case MQRCCF_MQOPEN_FAILED:
	             strcpy(rval, "MQRCCF_MQOPEN_FAILED");
		     break;
    		case MQRCCF_MQGET_FAILED:
	             strcpy(rval, "MQRCCF_MQGET_FAILED");
		     break;
    		case MQRCCF_MQPUT_FAILED:
	             strcpy(rval, "MQRCCF_MQPUT_FAILED");
		     break;
    		case MQRCCF_PING_ERROR:
	             strcpy(rval, "MQRCCF_PING_ERROR");
		     break;
    		case MQRCCF_CHANNEL_IN_USE:
	             strcpy(rval, "MQRCCF_CHANNEL_IN_USE");
		     break;
    		case MQRCCF_CHANNEL_NOT_FOUND:
	             strcpy(rval, "MQRCCF_CHANNEL_NOT_FOUND");
		     break;
    		case MQRCCF_UNKNOWN_REMOTE_CHANNEL:
	             strcpy(rval, "MQRCCF_UNKNOWN_REMOTE_CHANNEL");
		     break;
    		case MQRCCF_REMOTE_QM_UNAVAILABLE:
	             strcpy(rval, "MQRCCF_REMOTE_QM_UNAVAILABLE");
		     break;
    		case MQRCCF_REMOTE_QM_TERMINATING:
	             strcpy(rval, "MQRCCF_REMOTE_QM_TERMINATING");
		     break;
    		case MQRCCF_MQINQ_FAILED:
	             strcpy(rval, "MQRCCF_MQINQ_FAILED");
		     break;
    		case MQRCCF_NOT_XMIT_Q:
	             strcpy(rval, "MQRCCF_NOT_XMIT_Q");
		     break;
    		case MQRCCF_CHANNEL_DISABLED:
	             strcpy(rval, "MQRCCF_CHANNEL_DISABLED");
		     break;
    		case MQRCCF_USER_EXIT_NOT_AVAILABLE:
	             strcpy(rval, "MQRCCF_USER_EXIT_NOT_AVAILABLE");
		     break;
    		case MQRCCF_COMMIT_FAILED:
	             strcpy(rval, "MQRCCF_COMMIT_FAILED");
		     break;
    		case MQRCCF_CHANNEL_ALREADY_EXISTS:
	             strcpy(rval, "MQRCCF_CHANNEL_ALREADY_EXISTS");
		     break;
    		case MQRCCF_DATA_TOO_LARGE:
	             strcpy(rval, "MQRCCF_DATA_TOO_LARGE");
		     break;
    		case MQRCCF_CHANNEL_NAME_ERROR:
	             strcpy(rval, "MQRCCF_CHANNEL_NAME_ERROR");
		     break;
    		case MQRCCF_XMIT_Q_NAME_ERROR:
	             strcpy(rval, "MQRCCF_XMIT_Q_NAME_ERROR");
		     break;
    		case MQRCCF_MCA_NAME_ERROR:
	             strcpy(rval, "MQRCCF_MCA_NAME_ERROR");
		     break;
    		case MQRCCF_SEND_EXIT_NAME_ERROR:
	             strcpy(rval, "MQRCCF_SEND_EXIT_NAME_ERROR");
		     break;
    		case MQRCCF_SEC_EXIT_NAME_ERROR:
	             strcpy(rval, "MQRCCF_SEC_EXIT_NAME_ERROR");
		     break;
    		case MQRCCF_MSG_EXIT_NAME_ERROR:
	             strcpy(rval, "MQRCCF_MSG_EXIT_NAME_ERROR");
		     break;
    		case MQRCCF_RCV_EXIT_NAME_ERROR:
	             strcpy(rval, "MQRCCF_RCV_EXIT_NAME_ERROR");
		     break;
    		case MQRCCF_XMIT_Q_NAME_WRONG_TYPE:
	             strcpy(rval, "MQRCCF_EXIT_Q_NAME_WRONG_TYPE");
		     break;
    		case MQRCCF_MCA_NAME_WRONG_TYPE:
	             strcpy(rval, "MQRCCF_MCA_NAME_WRONG_TYPE");
		     break;
    		case MQRCCF_DISC_INT_WRONG_TYPE:
	             strcpy(rval, "MQRCCF_DISC_INT_WRONG_TYPE");
		     break;
    		case MQRCCF_SHORT_RETRY_WRONG_TYPE:
	             strcpy(rval, "MQRCCF_SHORT_RETRY_WRONG_TYPE");
		     break;
    		case MQRCCF_SHORT_TIMER_WRONG_TYPE:
	             strcpy(rval, "MQRCCF_SHORT_TIMER_WRONG_TYPE");
		     break;
    		case MQRCCF_LONG_RETRY_WRONG_TYPE:
	             strcpy(rval, "MQRCCF_LONG_RETRY_WRONG_TYPE");
		     break;
    		case MQRCCF_LONG_TIMER_WRONG_TYPE:
	             strcpy(rval, "MQRCCF_LONG_TIMER_WRONG_TYPE");
		     break;
    		case MQRCCF_PUT_AUTH_WRONG_TYPE:
	             strcpy(rval, "MQRCCF_PUT_AUTH_WRONG_TYPE");
		     break;
    		case MQRCCF_MISSING_CONN_NAME:
	             strcpy(rval, "MQRCCF_MISSING_CONN_NAME");
		     break;
    		case MQRCCF_CONN_NAME_ERROR:
	             strcpy(rval, "MQRCCF_CONN_NAME_ERROR");
		     break;
    		case MQRCCF_MQSET_FAILED:
	             strcpy(rval, "MQRCCF_MQSET_FAILED");
		     break;
    		case MQRCCF_CHANNEL_NOT_ACTIVE:
	             strcpy(rval, "MQRCCF_CHANNEL_NOT_ACTIVE");
		     break;
    		case MQRCCF_TERMINATED_BY_SEC_EXIT:
	             strcpy(rval, "MQRCCF_TERMINATED_BY_SEC_EXIT");
		     break;
    		case MQRCCF_DYNAMIC_Q_SCOPE_ERROR:
	             strcpy(rval, "MQRCCF_DYNAMIC_Q_SCOPE_ERROR");
		     break;
    		case MQRCCF_CELL_DIR_NOT_AVAILABLE:
	             strcpy(rval, "MQRCCF_CELL_DIR_NOT_AVAILABLE");
		     break;
    		case MQRC_NONE:
	             strcpy(rval, "MQRC_NONE");
		     break;
    		case MQRC_ALIAS_BASE_Q_TYPE_ERROR:
	             strcpy(rval, "MQRC_ALIAS_BASE_Q_TYPE_ERROR");
		     break;
    		case MQRC_ALREADY_CONNECTED:
	             strcpy(rval, "MQRC_ALREADY_CONNECTED");
		     break;
    		case MQRC_BACKED_OUT:
	             strcpy(rval, "MQRC_BACKED_OUT");
		     break;
    		case MQRC_BUFFER_ERROR:
	             strcpy(rval, "MQRC_BUFFER_ERROR");
		     break;
    		case MQRC_BUFFER_LENGTH_ERROR:
	             strcpy(rval, "MQRC_BUFFER_LENGTH_ERROR");
		     break;
    		case MQRC_CHAR_ATTR_LENGTH_ERROR:
	             strcpy(rval, "MQRC_CHAR_ATTR_LENGTH_ERROR");
		     break;
    		case MQRC_CHAR_ATTRS_ERROR:
	             strcpy(rval, "MQRC_CHAR_ATTRS_ERROR");
		     break;
    		case MQRC_CHAR_ATTRS_TOO_SHORT:
	             strcpy(rval, "MQRC_CHAR_ATTRS_TOO_SHORT");
		     break;
    		case MQRC_CONNECTION_BROKEN:
	             strcpy(rval, "MQRC_CONNECTION_BROKEN");
		     break;
		case MQRC_DATA_LENGTH_ERROR:
      			strcpy(rval, "MQRC_DATA_LENGTH_ERROR");
		     break;
		case MQRC_DYNAMIC_Q_NAME_ERROR:
      			strcpy(rval, "MQRC_DYNAMIC_Q_NAME_ERROR");
		     break;
		case MQRC_ENVIRONMENT_ERROR:
      			strcpy(rval, "MQRC_ENVIRONMENT_ERROR");
		     break;
		case MQRC_EXPIRY_ERROR:
      			strcpy(rval, "MQRC_EXPIRY_ERROR");
		     break;
		case MQRC_FEEDBACK_ERROR:
      			strcpy(rval, "MQRC_FEEDBACK_ERROR");
		     break;
		case MQRC_GET_INHIBITED:
      			strcpy(rval, "MQRC_GET_INHIBITED");
		     break;
		case MQRC_HANDLE_NOT_AVAILABLE:
      			strcpy(rval, "MQRC_HANDLE_NOT_AVAILABLE");
		     break;
		case MQRC_HCONN_ERROR:
      			strcpy(rval, "MQRC_HCONN_ERROR");
		     break;
		case MQRC_HOBJ_ERROR:
      			strcpy(rval, "MQRC_HOBJ_ERROR");
		     break;
		case MQRC_INHIBIT_VALUE_ERROR:
      			strcpy(rval, "MQRC_INHIBIT_VALUE_ERROR");
		     break;
		case MQRC_INT_ATTR_COUNT_ERROR:
      			strcpy(rval, "MQRC_INT_ATTR_COUNT_ERROR");
		     break;
		case MQRC_INT_ATTR_COUNT_TOO_SMALL:
      			strcpy(rval, "MQRC_INT_ATTR_COUNT_TOO_SMALL");
		     break;
		case MQRC_INT_ATTRS_ARRAY_ERROR:
      			strcpy(rval, "MQRC_INT_ATTRS_ARRAY_ERROR");
		     break;
		case MQRC_SYNCPOINT_LIMIT_REACHED:
      			strcpy(rval, "MQRC_SYNCPOINT_LIMIT_REACHED");
		     break;
		case MQRC_MAX_CONNS_LIMIT_REACHED:
      			strcpy(rval, "MQRC_MAX_CONNS_LIMIT_REACHED");
		     break;
		case MQRC_MD_ERROR:
      			strcpy(rval, "MQRC_MD_ERROR");
		     break;
		case MQRC_MISSING_REPLY_TO_Q:
      			strcpy(rval, "MQRC_MISSING_REPLY_TO_Q");
		     break;
		case MQRC_MSG_TYPE_ERROR:
      			strcpy(rval, "MQRC_MSG_TYPE_ERROR");
		     break;
		case MQRC_MSG_TOO_BIG_FOR_Q:
      			strcpy(rval, "MQRC_MSG_TOO_BIG_FOR_Q");
		     break;
		case MQRC_MSG_TOO_BIG_FOR_Q_MGR:
      			strcpy(rval, "MQRC_MSG_TOO_BIG_FOR_Q_MGR");
		     break;
		case MQRC_NO_MSG_AVAILABLE:
      			strcpy(rval, "MQRC_NO_MSG_AVAILABLE");
		     break;
		case MQRC_NO_MSG_UNDER_CURSOR:
      			strcpy(rval, "MQRC_NO_MSG_UNDER_CURSOR");
		     break;
		case MQRC_NOT_AUTHORIZED:
      			strcpy(rval, "MQRC_NOT_AUTHORIZED");
		     break;
		case MQRC_NOT_OPEN_FOR_BROWSE:
      			strcpy(rval, "MQRC_NOT_OPEN_FOR_BROWSE");
		     break;
		case MQRC_NOT_OPEN_FOR_INPUT:
      			strcpy(rval, "MQRC_NOT_OPEN_FOR_INPUT");
		     break;
		case MQRC_NOT_OPEN_FOR_INQUIRE:
      			strcpy(rval, "MQRC_NOT_OPEN_FOR_INQUIRE");
		     break;
		case MQRC_NOT_OPEN_FOR_OUTPUT:
      			strcpy(rval, "MQRC_NOT_OPEN_FOR_OUTPUT");
		     break;
		case MQRC_NOT_OPEN_FOR_SET:
      			strcpy(rval, "MQRC_NOT_OPEN_FOR_SET");
		     break;
		case MQRC_OBJECT_CHANGED:
      			strcpy(rval, "MQRC_OBJECT_CHANGED");
		     break;
		case MQRC_OBJECT_IN_USE:
      			strcpy(rval, "MQRC_OBJECT_IN_USE");
		     break;
		case MQRC_OBJECT_TYPE_ERROR:
      			strcpy(rval, "MQRC_OBJECT_TYPE_ERROR");
		     break;
		case MQRC_OD_ERROR:
      			strcpy(rval, "MQRC_OD_ERROR");
		     break;
		case MQRC_OPTION_NOT_VALID_FOR_TYPE:
      			strcpy(rval, "MQRC_OPTION_NOT_VALID_FOR_TYPE");
		     break;
		case MQRC_OPTIONS_ERROR:
      			strcpy(rval, "MQRC_OPTIONS_ERROR");
		     break;
		case MQRC_PERSISTENCE_ERROR:
      			strcpy(rval, "MQRC_PERSISTENCE_ERROR");
		     break;
		case MQRC_PERSISTENT_NOT_ALLOWED:
      			strcpy(rval, "MQRC_PERSISTENT_NOT_ALLOWED");
		     break;
		case MQRC_PRIORITY_EXCEEDS_MAXIMUM:
      			strcpy(rval, "MQRC_PRIORITY_EXCEEDS_MAXIMUM");
		     break;
		case MQRC_PRIORITY_ERROR:
      			strcpy(rval, "MQRC_PRIORITY_ERROR");
		     break;
		case MQRC_PUT_INHIBITED:
      			strcpy(rval, "MQRC_PUT_INHIBITED");
		     break;
		case MQRC_Q_DELETED:
      			strcpy(rval, "MQRC_Q_DELETED");
		     break;
		case MQRC_Q_FULL:
      			strcpy(rval, "MQRC_Q_FULL");
		     break;
		case MQRC_Q_NOT_EMPTY:
      			strcpy(rval, "MQRC_Q_NOT_EMPTY");
		     break;
		case MQRC_Q_SPACE_NOT_AVAILABLE:
      			strcpy(rval, "MQRC_Q_SPACE_NOT_AVAILABLE");
		     break;
		case MQRC_Q_TYPE_ERROR:
      			strcpy(rval, "MQRC_Q_TYPE_ERROR");
		     break;
		case MQRC_Q_MGR_NAME_ERROR:
      			strcpy(rval, "MQRC_Q_MGR_NAME_ERROR");
		     break;
		case MQRC_Q_MGR_NOT_AVAILABLE:
      			strcpy(rval, "MQRC_Q_MGR_NOT_AVAILABLE");
		     break;
		case MQRC_REPORT_OPTIONS_ERROR:
      			strcpy(rval, "MQRC_REPORT_OPTIONS_ERROR");
		     break;
		case MQRC_SECOND_MARK_NOT_ALLOWED:
      			strcpy(rval, "MQRC_SECOND_MARK_NOT_ALLOWED");
		     break;
		case MQRC_SECURITY_ERROR:
      			strcpy(rval, "MQRC_SECURITY_ERROR");
		     break;
		case MQRC_SELECTOR_COUNT_ERROR:
      			strcpy(rval, "MQRC_SELECTOR_COUNT_ERROR");
		     break;
		case MQRC_SELECTOR_LIMIT_EXCEEDED:
      			strcpy(rval, "MQRC_SELECTOR_LIMIT_EXCEEDED");
		     break;
		case MQRC_SELECTOR_ERROR:
      			strcpy(rval, "MQRC_SELECTOR_ERROR");
		     break;
		case MQRC_SELECTOR_NOT_FOR_TYPE:
      			strcpy(rval, "MQRC_SELECTOR_NOT_FOR_TYPE");
		     break;
		case MQRC_SIGNAL_OUTSTANDING:
      			strcpy(rval, "MQRC_SIGNAL_OUTSTANDING");
		     break;
		case MQRC_SIGNAL_REQUEST_ACCEPTED:
      			strcpy(rval, "MQRC_SIGNAL_REQUEST_ACCEPTED");
		     break;
		case MQRC_STORAGE_NOT_AVAILABLE:
      			strcpy(rval, "MQRC_STORAGE_NOT_AVAILABLE");
		     break;
		case MQRC_SYNCPOINT_NOT_AVAILABLE:
      			strcpy(rval, "MQRC_SYNCPOINT_NOT_AVAILABLE");
		     break;
    		case MQRC_TRIGGER_CONTROL_ERROR:
      			strcpy(rval, "MQRC_TRIGGER_CONTROL_ERROR");
		     break;
    		case MQRC_TRIGGER_DEPTH_ERROR:
      			strcpy(rval, "MQRC_TRIGGER_DEPTH_ERROR");
		     break;
    		case MQRC_TRIGGER_MSG_PRIORITY_ERR:
      			strcpy(rval, "MQRC_TRIGGER_MSG_PRIORITY_ERR");
		     break;
    		case MQRC_TRIGGER_TYPE_ERROR:
      			strcpy(rval, "MQRC_TRIGGER_TYPE_ERROR");
		     break;
    		case MQRC_TRUNCATED_MSG_ACCEPTED:
      			strcpy(rval, "MQRC_TRUNCATED_MSG_ACCEPTED");
		     break;
    		case MQRC_TRUNCATED_MSG_FAILED:
      			strcpy(rval, "MQRC_TRUNCATED_MSG_FAILED");
		     break;
    		case MQRC_UNKNOWN_ALIAS_BASE_Q:
      			strcpy(rval, "MQRC_UNKNOWN_ALIAS_BASE_Q");
		     break;
    		case MQRC_UNKNOWN_OBJECT_NAME:
      			strcpy(rval, "MQRC_UNKNOWN_OBJECT_NAME");
		     break;
    		case MQRC_UNKNOWN_OBJECT_Q_MGR:
      			strcpy(rval, "MQRC_UNKNOWN_OBJECT_Q_MGR");
		     break;
    		case MQRC_UNKNOWN_REMOTE_Q_MGR:
      			strcpy(rval, "MQRC_UNKNOWN_REMOTE_Q_MGR");
		     break;
    		case MQRC_WAIT_INTERVAL_ERROR:
     			 strcpy(rval, "MQRC_WAIT_INTERVAL_ERROR");
		     break;
    		case MQRC_XMIT_Q_TYPE_ERROR:
     			 strcpy(rval, "MQRC_XMIT_Q_TYPE_ERROR");
		     break;
    		case MQRC_XMIT_Q_USAGE_ERROR:
      			strcpy(rval, "MQRC_XMIT_Q_USAGE_ERROR");
		     break;
    		case MQRC_NOT_OPEN_FOR_PASS_ALL:
      			strcpy(rval, "MQRC_NOT_OPEN_FOR_PASS_ALL");
		     break;
    		case MQRC_NOT_OPEN_FOR_PASS_IDENT:
      			strcpy(rval, "MQRC_NOT_OPEN_FOR_PASS_IDENT");
		     break;
   	        case MQRC_NOT_OPEN_FOR_SET_ALL:
      			strcpy(rval, "MQRC_NOT_OPEN_FOR_SET_ALL");
		     break;
    		case MQRC_NOT_OPEN_FOR_SET_IDENT:
      			strcpy(rval, "MQRC_NOT_OPEN_FOR_SET_IDENT");
		     break;
    		case MQRC_CONTEXT_HANDLE_ERROR:
      			strcpy(rval, "MQRC_CONTEXT_HANDLE_ERROR");
		     break;
    		case MQRC_CONTEXT_NOT_AVAILABLE:
      			strcpy(rval, "MQRC_CONTEXT_NOT_AVAILABLE");
		     break;
    		case MQRC_SIGNAL1_ERROR:
      			strcpy(rval, "MQRC_SIGNAL1_ERROR");
		     break;
    		case MQRC_OBJECT_ALREADY_EXISTS:
      			strcpy(rval, "MQRC_OBJECT_ALREADY_EXISTS");
		     break;
    		case MQRC_OBJECT_DAMAGED:
      			strcpy(rval, "MQRC_OBJECT_DAMAGED");
		     break;
    		case MQRC_RESOURCE_PROBLEM:
      			strcpy(rval, "MQRC_RESOURCE_PROBLEM");
		     break;
    		case MQRC_ANOTHER_Q_MGR_CONNECTED:
      			strcpy(rval, "MQRC_ANOTHER_Q_MGR_CONNECTED");
		     break;
    		case MQRC_UNKNOWN_REPORT_OPTION:
      			strcpy(rval, "MQRC_UNKNOWN_REPORT_OPTION");
		     break;
    		case MQRC_SUPPRESSED_BY_EXIT:
      			strcpy(rval, "MQRC_SUPPRESSED_BY_EXIT");
		     break;
    		case MQRC_FORMAT_ERROR:
      			strcpy(rval, "MQRC_FORMAT_ERROR");
		     break;
    		case MQRC_SOURCE_CCSID_ERROR:
      			strcpy(rval, "MQRC_SOURCE_CCSID_ERROR");
		     break;
    		case MQRC_SOURCE_INTEGER_ENC_ERROR:
      			strcpy(rval, "MQRC_SOURCE_INTEGER_ENC_ERROR");
		     break;
    		case MQRC_SOURCE_DECIMAL_ENC_ERROR:
      			strcpy(rval, "MQRC_SOURCE_DECIMAL_ENC_ERROR");
		     break;
    		case MQRC_SOURCE_FLOAT_ENC_ERROR:
      			strcpy(rval, "MQRC_SOURCE_FLOAT_ENC_ERROR");
		     break;
    		case MQRC_TARGET_CCSID_ERROR:
      			strcpy(rval, "MQRC_TARGET_CCSID_ERROR");
		     break;
    		case MQRC_TARGET_INTEGER_ENC_ERROR:
      			strcpy(rval, "MQRC_TARGET_INTEGER_ENC_ERROR");
		     break;
    		case MQRC_TARGET_DECIMAL_ENC_ERROR:
      			strcpy(rval, "MQRC_TARGET_DECIMAL_ENC_ERROR");
		     break;
    		case MQRC_TARGET_FLOAT_ENC_ERROR:
      			strcpy(rval, "MQRC_TARGET_FLOAT_ENC_ERROR");
		     break;
    		case MQRC_NOT_CONVERTED:
      			strcpy(rval, "MQRC_NOT_CONVERTED");
		     break;
    		case MQRC_CONVERTED_MSG_TOO_BIG:
      			strcpy(rval, "MQRC_CONVERTED_MSG_TOO_BIG");
		     break;
    		case MQRC_ADAPTER_STORAGE_SHORTAGE:
      			strcpy(rval, "MQRC_ADAPTER_STORAGE_SHORTAGE");
		     break;
    		case MQRC_ADAPTER_CONN_LOAD_ERROR:
      			strcpy(rval, "MQRC_ADAPTER_CONN_LOAD_ERROR");
		     break;
    		case MQRC_ADAPTER_SERV_LOAD_ERROR:
      			strcpy(rval, "MQRC_ADAPTER_SERV_LOAD_ERROR");
		     break;
    		case MQRC_ADAPTER_DEFS_ERROR:
      			strcpy(rval, "MQRC_ADAPTER_DEFS_ERROR");
		     break;
    		case MQRC_ADAPTER_DEFS_LOAD_ERROR:
      			strcpy(rval, "MQRC_ADAPTER_DEFS_LOAD_ERROR");
		     break;
    		case MQRC_ADAPTER_DISC_LOAD_ERROR:
      			strcpy(rval, "MQRC_ADAPTER_DISC_LOAD_ERROR");
		     break;
    		case MQRC_CICS_WAIT_FAILED:
      			strcpy(rval, "MQRC_CICS_WAIT_FAILED");
		     break;
    		case MQRC_SOURCE_LENGTH_ERROR:
      			strcpy(rval, "MQRC_SOURCE_LENGTH_ERROR");
		     break;
    		case MQRC_TARGET_LENGTH_ERROR:
      			strcpy(rval, "MQRC_TARGET_LENGTH_ERROR");
		     break;
    		case MQRC_SOURCE_BUFFER_ERROR:
      			strcpy(rval, "MQRC_SOURCE_BUFFER_ERROR");
		     break;
    		case MQRC_TARGET_BUFFER_ERROR:
      			strcpy(rval, "MQRC_TARGET_BUFFER_ERROR");
		     break;
    		case MQRC_DBCS_ERROR:
      			strcpy(rval, "MQRC_DBCS_ERROR");
		     break;
    		case MQRC_ASID_MISMATCH:
      			strcpy(rval, "MQRC_ASID_MISMATCH");
		     break;
    		case MQRC_CONN_ID_IN_USE:
      			strcpy(rval, "MQRC_CONN_ID_IN_USE");
		     break;
    		case MQRC_Q_MGR_QUIESCING:
      			strcpy(rval, "MQRC_Q_MGR_QUIESCING");
		     break;
    		case MQRC_Q_MGR_STOPPING:
      			strcpy(rval, "MQRC_Q_MGR_STOPPING");
		     break;
    		case MQRC_DUPLICATE_RECOV_COORD:
      			strcpy(rval, "MQRC_DUPLICATE_RECOV_COORD");
		     break;
    		case MQRC_PMO_ERROR:
      			strcpy(rval, "MQRC_PMO_ERROR");
		     break;
    		case MQRC_API_EXIT_NOT_FOUND:
      			strcpy(rval, "MQRC_API_EXIT_NOT_FOUND");
		     break;
    		case MQRC_API_EXIT_LOAD_ERROR:
      			strcpy(rval, "MQRC_API_EXIT_LOAD_ERROR");
		     break;
    		case MQRC_REMOTE_Q_NAME_ERROR:
      			strcpy(rval, "MQRC_REMOTE_Q_NAME_ERROR");
		     break;
    		case MQRC_GMO_ERROR:
      			strcpy(rval, "MQRC_GMO_ERROR");
		     break;
    		case MQRC_PAGESET_FULL:
      			strcpy(rval, "MQRC_PAGESET_FULL");
		     break;
    		case MQRC_PAGESET_ERROR:
      			strcpy(rval, "MQRC_PAGESET_ERROR");
		     break;
    		case MQRC_NAME_NOT_VALID_FOR_TYPE:
      			strcpy(rval, "MQRC_NAME_NOT_VALID_FOR_TYPE");
		     break;
    		case MQRC_UNEXPECTED_ERROR:
      			strcpy(rval, "MQRC_UNEXPECTED_ERROR");
		     break;
    		case MQRC_UNKNOWN_XMIT_Q:
      			strcpy(rval, "MQRC_UNKNOWN_XMIT_Q");
		     break;
    		case MQRC_UNKNOWN_DEF_XMIT_Q:
      			strcpy(rval, "MQRC_UNKNOWN_DEF_XMIT_Q");
		     break;
    		case MQRC_DEF_XMIT_Q_TYPE_ERROR:
      			strcpy(rval, "MQRC_DEF_XMIT_Q_TYPE_ERROR");
		     break;
    		case MQRC_DEF_XMIT_Q_USAGE_ERROR:
      			strcpy(rval, "MQRC_DEF_XMIT_Q_USAGE_ERROR");
		     break;
    		case MQRC_NAME_IN_USE:
      			strcpy(rval, "MQRC_NAME_IN_USE");
		     break;
    		case MQRC_CONNECTION_QUIESCING:
      			strcpy(rval, "MQRC_CONNECTION_QUIESCING");
		     break;
    		case MQRC_CONNECTION_STOPPING:
      			strcpy(rval, "MQRC_CONNECTION_STOPPING");
		     break;
    		case MQRC_ADAPTER_NOT_AVAILABLE:
      			strcpy(rval, "MQRC_ADAPTER_NOT_AVAILABLE");
		     break;
    		case MQRC_MSG_ID_ERROR:
      			strcpy(rval, "MQRC_MSG_ID_ERROR");
		     break;
    		case MQRC_CORREL_ID_ERROR:
      			strcpy(rval, "MQRC_CORREL_ID_ERROR");
		     break;
    		case MQRC_FILE_SYSTEM_ERROR:
      			strcpy(rval, "MQRC_FILE_SYSTEM_ERROR");
		     break;
    		case MQRC_NO_MSG_LOCKED:
      			strcpy(rval, "MQRC_NO_MSG_LOCKED");
		     break;
    		case MQRC_CONNECTION_NOT_AUTHORIZED:
      			strcpy(rval, "MQRC_CONNECTION_NOT_AUTHORIZED");
		     break;
    		case MQRC_MSG_TOO_BIG_FOR_CHANNEL:
      			strcpy(rval, "MQRC_MSG_TOO_BIG_FOR_CHANNEL");
		     break;
    		case MQRC_CALL_IN_PROGRESS:
      			strcpy(rval, "MQRC_CALL_IN_PROGRESS");
		     break;
    		case MQRC_Q_MGR_ACTIVE:
      			strcpy(rval, "MQRC_Q_MGR_ACTIVE");
		     break;
    		case MQRC_Q_MGR_NOT_ACTIVE:
      			strcpy(rval, "MQRC_Q_MGR_NOT_ACTIVE");
		     break;
    		case MQRC_Q_DEPTH_HIGH:
      			strcpy(rval, "MQRC_Q_DEPTH_HIGH");
		     break;
    		case MQRC_Q_DEPTH_LOW:
      			strcpy(rval, "MQRC_Q_DEPTH_LOW");
		     break;
    		case MQRC_Q_SERVICE_INTERVAL_HIGH:
      			strcpy(rval, "MQRC_Q_SERVICE_INTERVAL_HIGH");
		     break;
    		case MQRC_Q_SERVICE_INTERVAL_OK:
      			strcpy(rval, "MQRC_Q_SERVICE_INTERVAL_OK");
		     break;
    		case MQRC_HCONFIG_ERROR:
      			strcpy(rval, "MQRC_HCONFIG_ERROR");
		     break;
    		case MQRC_FUNCTION_ERROR:
      			strcpy(rval, "MQRC_FUNCTION_ERROR");
		     break;
    		case MQRC_CHANNEL_STARTED:
      			strcpy(rval, "MQRC_CHANNEL_STARTED");
		     break;
    		case MQRC_CHANNEL_STOPPED:
      			strcpy(rval, "MQRC_CHANNEL_STOPPED");
		     break;
    		case MQRC_CHANNEL_CONV_ERROR:
      			strcpy(rval, "MQRC_CHANNEL_CONV_ERROR");
		     break;
    		case MQRC_SERVICE_NOT_AVAILABLE:
      			strcpy(rval, "MQRC_SERVICE_NOT_AVAILABLE");
		     break;
    		case MQRC_INITIALIZATION_FAILED:
      			strcpy(rval, "MQRC_INITIALIZATION_FAILED");
		     break;
    		case MQRC_TERMINATION_FAILED:
      			strcpy(rval, "MQRC_TERMINATION_FAILED");
		     break;
    		case MQRC_UNKNOWN_Q_NAME:
      			strcpy(rval, "MQRC_UNKNOWN_Q_NAME");
		     break;
    		case MQRC_SERVICE_ERROR:
      			strcpy(rval, "MQRC_SERVICE_ERROR");
		     break;
    		case MQRC_Q_ALREADY_EXISTS:
      			strcpy(rval, "MQRC_Q_ALREADY_EXISTS");
		     break;
    		case MQRC_USER_ID_NOT_AVAILABLE:
      			strcpy(rval, "MQRC_USER_ID_NOT_AVAILABLE");
		     break;
    		case MQRC_UNKNOWN_ENTITY:
      			strcpy(rval, "MQRC_UNKNOWN_ENTITY");
		     break;
    		case MQRC_UNKNOWN_AUTH_ENTITY:
      			strcpy(rval, "MQRC_UNKNOWN_AUTH_ENTITY");
		     break;
		default:
		     dspfl=1;
		     break;
	}
        
        if(dspfl == 1)
        {
	   dspfl = 0;
           switch(dspRes)
           {
    		case MQRC_TRUNCATED:
      			strcpy(rval, "MQRC_TRUNCATED");
		     break;
    		case MQRC_UNKNOWN_REF_OBJECT:		
      			strcpy(rval, "MQRC_UNKNOWN_REF_OBJECT");
		     break;
           }
         }
		

   	if(outTypeDs == 'B' || outTypeDs == 'S')
		printf("Reason Code                   : %s\n", rval);

   	if(outTypeDs == 'B' || outTypeDs == 'F')
		fprintf(dr, "Reason Code                   : %s\n", rval);
 
   	return 0;
}  /* end of display reason function */
    		
